import numpy as np
import matplotlib.pyplot as plt
import astropy.units as u

from dust_extinction.dust_extinction import (F99,
                                             G03_SMCBar,
                                             G03_LMCAvg,
                                             G03_LMC2)

fig, ax = plt.subplots()

# generate the curves and plot them
x = np.arange(0.3,10.0,0.1)/u.micron

ext_model = F99()
ax.plot(x,ext_model(x),label='MW Average (F99 w/ $R(V)=3.1$)')

ext_model = G03_SMCBar()
ax.plot(x,ext_model(x),label='G03 SMCBar')

ext_model = G03_LMCAvg()
ax.plot(x,ext_model(x),label='G03 LMCAvg')

ext_model = G03_LMC2()
ax.plot(x,ext_model(x),label='G03 LMC2')

ax.set_xlabel('$x$ [$\mu m^{-1}$]')
ax.set_ylabel('$A(x)/A(V)$')

ax.legend(loc='best')
plt.tight_layout()
plt.show()